@@ -3,9 +3,6 @@ use r2d2_oracle::OracleConnectionManager;
 use r2d2::{Pool, PooledConnection};
 use parking_lot::{ RwLock};
 use std::time::Duration;
-use serde::{Serialize};
-use std::fmt::{Display, Formatter, Result as FmtResult};
-use serde_json::{to_string_pretty};
 
 use crate::{DB_PROPERTIES};
 
